import Vue from "vue";
import VueRouter from "vue-router";

import modelLibrary from "./modelLibrary"; // 模型库
import algorithmsLibrary from "./algorithmsLibrary"; // 算法库
import sceneLibrary from "./sceneLibrary"; // 场景库
import systemManagement from "./systemManagement"; // 账户管理
import workManagement from "./workManagement"; // 工作管理
import multimodeSimulation from './multimodeSimulation'; // 多模式仿真
import personalInformation from "./personalInformation"

Vue.use(VueRouter);

const routes = [{
  path: "/login",
  name: "login",
  component: () => import("../views/login.vue")
},
{
  path: "/",
  name: "index",
  meta: {
    tabname: "首页"
  },
  component: () => import('../views/index'),
  redirect: '/mainPage',
  children: [
    {
      path: "/mainPage",
      name: "mainPage",
      meta: {
        // tabname: "首页"
        login: true
      },
      component: () => import("@/views/mainPage.vue")
    },
    {
      path: "/modelLibrary",
      name: "modelLibrary",
      meta: {
        tabname: "模型库",
        login: true
      },
      component: () => import("@/views/modelLibrary/index"),
      redirect: '/index',
      children: modelLibrary,
    },
    {
      path: "/algorithmsLibrary",
      name: "algorithmsLibrary",
      meta: {
        tabname: "算法库",
        login: true
      },
      component: () => import("@/views/algorithmsLibrary/index"),
      redirect: '/index',
      children: algorithmsLibrary,
    },
    {
      path: "/sceneLibrary",
      name: "sceneLibrary",
      meta: {
        tabname: "场景库",
        login: true
      },
      component: () => import("@/views/sceneLibrary/index"),
      redirect: '/index',
      children: sceneLibrary,
    },
    {
      path: "/workManagement",
      name: "workManagement",
      meta: {
        tabname: "工作管理",
        login: true
      },
      component: () => import("@/views/workManagement/index"),
      redirect: '/index',
      children: workManagement,
    },
    {
      path: "/systemManagement",
      name: "systemManagement",
      meta: {
        tabname: "系统管理",
        login: true
      },
      component: () => import("@/views/systemManagement/index"),
      redirect: '/index',
      children: systemManagement,
    },
    {
      path: "/personalInformation",
      name: "personalInformation",
      meta: {
        tabname: "个人信息",
        login: true
      },
      component: () => import("@/views/personalInformation/personalInformation"),
      // redirect: '/index',
      // children: personalInformation,
    },
    {
      path: "/test",
      name: "multimodeSimulation",
      meta: {
        tabname: "多模式仿真",
        login: true
      },
      component: () => import("@/views/multimodeSimulation"),
    },
    {
      path: "test2",
      name: "simulationEdit",
      meta: {
        tabname: "多模式仿真详情",
        menuKind: "simulationEdit",
        login: true
      },
      component: () => import("@/views/multimodeSimulation/simulationEdit.vue")
    },
    {
      path: "test3",
      name: "evaluationResults",
      meta: {
        tabname: "多模式仿真评价结果",
        menuKind: "evaluationResults",
        login: true
      },
      component: () => import("@/views/multimodeSimulation/evaluationResults.vue")
    }
  ]
  // .concat([{
  //   path: "*",
  //   name: "*",
  //   component: () => import("../views/mainPage.vue")
  // }, ]),
},
{
  path: "*",
  name: "*",
  component: () => import("@/views/mainPage.vue")
}
];

const router = new VueRouter({
  mode: "history",
  base: process.env.BASE_URL,
  routes,
  scrollBehavior (to, from, savedPosition) {
    return {
      x: 0,
      y: 0
    }
  }
});

export default router;